==> jc-1.4.0.tar.gz: polyglot/visit/TypeChecker.h <==
// public class polyglot.visit.TypeChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 478d58036bde3016 polyglot_visit_TypeChecker

// header file dependencies
// @dep_header polyglot_visit_ContextVisitor

#include "polyglot/visit/ContextVisitor.h"

#ifndef _JC_polyglot_visit_TypeChecker_H_
#define _JC_polyglot_visit_TypeChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_TypeChecker$sub_refs	_jc_polyglot_visit_TypeChecker$sub_refs;
typedef struct _jc_polyglot_visit_TypeChecker$sub_nonrefs	_jc_polyglot_visit_TypeChecker$sub_nonrefs;
typedef struct _jc_polyglot_visit_TypeChecker$refs	_jc_polyglot_visit_TypeChecker$refs;
typedef struct _jc_polyglot_visit_TypeChecker$nonrefs	_jc_polyglot_visit_TypeChecker$nonrefs;
typedef struct _jc_polyglot_visit_TypeChecker$object	_jc_polyglot_visit_TypeChecker$object;

typedef const struct _jc_polyglot_visit_TypeChecker$vmethods	_jc_polyglot_visit_TypeChecker$vmethods;
typedef const struct _jc_polyglot_visit_TypeChecker$vtable	_jc_polyglot_visit_TypeChecker$vtable;
typedef const struct _jc_polyglot_visit_TypeChecker$vtype	_jc_polyglot_visit_TypeChecker$vtype;

// Constructors
extern void _jc_polyglot_visit_TypeChecker$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_TypeChecker$method$enterCall$3637fb21939178bc(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_TypeChecker$method$leaveCall$9236e830bcef4b36(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_TypeChecker$method_info$enterCall$3637fb21939178bc;
extern _jc_method _jc_polyglot_visit_TypeChecker$method_info$leaveCall$9236e830bcef4b36;

// Virtual methods structure
struct _jc_polyglot_visit_TypeChecker$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enterCall$3637fb21939178bc)(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_object	*(*leaveCall$9236e830bcef4b36)(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_polyglot_visit_TypeChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_TypeChecker$vmethods	polyglot_visit_TypeChecker;
};

// Vtype
struct _jc_polyglot_visit_TypeChecker$vtype {
	_jc_type			type;
	_jc_polyglot_visit_TypeChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_TypeChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_TypeChecker$refs {
    _jc_polyglot_visit_TypeChecker$sub_refs	polyglot_visit_TypeChecker;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_TypeChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_TypeChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_TypeChecker$sub_nonrefs	polyglot_visit_TypeChecker;
};

// Object instance structure
struct _jc_polyglot_visit_TypeChecker$object {
	_jc_polyglot_visit_TypeChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_TypeChecker$vtype	*vtype;
	_jc_polyglot_visit_TypeChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_TypeChecker$vtype _jc_polyglot_visit_TypeChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_TypeChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_TypeChecker$class_object;

#endif	/* _JC_polyglot_visit_TypeChecker_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/TypeChecker.h <==
// public class polyglot.visit.TypeChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 478d58036bde3016 polyglot_visit_TypeChecker

// header file dependencies
// @dep_header polyglot_visit_ContextVisitor

#include "polyglot/visit/ContextVisitor.h"

#ifndef _JC_polyglot_visit_TypeChecker_H_
#define _JC_polyglot_visit_TypeChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_TypeChecker$sub_refs	_jc_polyglot_visit_TypeChecker$sub_refs;
typedef struct _jc_polyglot_visit_TypeChecker$sub_nonrefs	_jc_polyglot_visit_TypeChecker$sub_nonrefs;
typedef struct _jc_polyglot_visit_TypeChecker$refs	_jc_polyglot_visit_TypeChecker$refs;
typedef struct _jc_polyglot_visit_TypeChecker$nonrefs	_jc_polyglot_visit_TypeChecker$nonrefs;
typedef struct _jc_polyglot_visit_TypeChecker$object	_jc_polyglot_visit_TypeChecker$object;

typedef const struct _jc_polyglot_visit_TypeChecker$vmethods	_jc_polyglot_visit_TypeChecker$vmethods;
typedef const struct _jc_polyglot_visit_TypeChecker$vtable	_jc_polyglot_visit_TypeChecker$vtable;
typedef const struct _jc_polyglot_visit_TypeChecker$vtype	_jc_polyglot_visit_TypeChecker$vtype;

// Constructors
extern void _jc_polyglot_visit_TypeChecker$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_TypeChecker$method$enterCall$3637fb21939178bc(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_TypeChecker$method$leaveCall$9236e830bcef4b36(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_TypeChecker$method_info$enterCall$3637fb21939178bc;
extern _jc_method _jc_polyglot_visit_TypeChecker$method_info$leaveCall$9236e830bcef4b36;

// Virtual methods structure
struct _jc_polyglot_visit_TypeChecker$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enterCall$3637fb21939178bc)(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leaveCall$9236e830bcef4b36)(_jc_env *, struct _jc_polyglot_visit_TypeChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_TypeChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_TypeChecker$vmethods	polyglot_visit_TypeChecker;
};

// Vtype
struct _jc_polyglot_visit_TypeChecker$vtype {
	_jc_type			type;
	_jc_polyglot_visit_TypeChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_TypeChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_TypeChecker$refs {
    _jc_polyglot_visit_TypeChecker$sub_refs	polyglot_visit_TypeChecker;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_TypeChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_TypeChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_TypeChecker$sub_nonrefs	polyglot_visit_TypeChecker;
};

// Object instance structure
struct _jc_polyglot_visit_TypeChecker$object {
	_jc_polyglot_visit_TypeChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_TypeChecker$vtype	*vtype;
	_jc_polyglot_visit_TypeChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_TypeChecker$vtype _jc_polyglot_visit_TypeChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_TypeChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_TypeChecker$class_object;

#endif	/* _JC_polyglot_visit_TypeChecker_H_ */
